@@ -546,6 +546,68 @@ db_of_parts["charger-socket"] = Part(
     ],
 )
 
+db_of_parts["220VAC-dimmer"] = Part(
+    info=[
+        "220VAC dimmer",
+    ],
+    images=[
+        "220VAC-dimmer.jpeg",
+    ],
+)
+
+db_of_parts["resistance-heating-wire"] = Part(
+    info=[
+        "resistance heating wire",
+    ],
+    images=[
+        "resistance-heating-wire.jpg",
+    ],
+)
+
+db_of_parts["ceramic-terminal"] = Part(
+    info=[
+        "ceramic terminal",
+    ],
+    images=[
+        "ceramic-terminal.jpg",
+    ],
+)
+
+db_of_parts["mountable-digital-thermometer"] = Part(
+    info=[
+        "mountable digital thermometer",
+    ],
+    images=[
+        "mountable-digital-thermometer.jpeg",
+    ],
+)
+
+db_of_parts["pwm-manual-dc-motor-controller"] = Part(
+    info=[
+        "pwm manual DC motor controller, 12 V, ≥ 5 A",
+    ],
+    images=[
+        "pwm-manual-dc-motor-controller.jpg",
+    ],
+)
+
+db_of_parts["heater-element"] = Part(
+    info=[
+        "heater element",
+    ],
+    images=[
+        "heater-element.jpg",
+    ],
+)
+
+db_of_parts["sd-card-32-gb"] = Part(
+    info=[
+        "SD card, 32 GB",
+    ],
+    images=[
+        "sd-card-32-gb.jpg",
+    ],
+)
 
 db_of_parts["template"] = Part(
     info=[
